@@ -26,24 +26,17 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.sql.DataSource;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 /**
  * TestSuite for BasicDataSource
  *
  * @author Dirk Verbeeck
- * @version $Revision: 1572217 $ $Date: 2014-02-26 19:49:46 +0000 (Wed, 26 Feb 2014) $
+ * @version $Revision: 1587109 $ $Date: 2014-04-13 15:07:42 -0700 (Sun, 13 Apr 2014) $
  */
 public class TestBasicDataSource extends TestConnectionPool {
     public TestBasicDataSource(String testName) {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestBasicDataSource.class);
-    }
-
     @Override
     protected Connection getConnection() throws Exception {
         return ds.getConnection();
@@ -577,4 +570,4 @@ class TesterConnRequestCountDriver extends TesterDriver {
     public static void initConnRequestCount() {
         connectionRequestCount.set(0);
     }
-}
\ No newline at end of file
+}
