@@ -26,9 +26,6 @@ import java.util.ArrayList;
 
 import javax.sql.DataSource;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
 import org.apache.commons.dbcp2.DelegatingStatement;
 import org.apache.commons.dbcp2.TestConnectionPool;
 import org.apache.commons.dbcp2.TesterDriver;
@@ -37,17 +34,13 @@ import org.apache.commons.dbcp2.cpdsadapter.DriverAdapterCPDS;
 /**
  * @author John McNally
  * @author Dirk Verbeeck
- * @version $Revision: 1572084 $ $Date: 2014-02-26 15:11:39 +0000 (Wed, 26 Feb 2014) $
+ * @version $Revision: 1587109 $ $Date: 2014-04-13 15:07:42 -0700 (Sun, 13 Apr 2014) $
  */
 public class TestSharedPoolDataSource extends TestConnectionPool {
     public TestSharedPoolDataSource(String testName) {
         super(testName);
     }
 
-    public static Test suite() {
-        return new TestSuite(TestSharedPoolDataSource.class);
-    }
-
     @Override
     protected Connection getConnection() throws Exception {
         return ds.getConnection("foo","bar");
@@ -612,4 +605,4 @@ public class TestSharedPoolDataSource extends TestConnectionPool {
             // Ignore
         }
     }
-}
\ No newline at end of file
+}
